==> haskell-th-utilities-0.2.5.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-utilities
version:              0.2.5.1
visibility:           public
id:                   th-utilities-0.2.5.1-t64btWfiMa44UE3pSm6kk
key:                  th-utilities-0.2.5.1-t64btWfiMa44UE3pSm6kk
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  c5fe3c52631ce0acf61bc7c52122a905
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/th-utilities-0.2.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/th-utilities-0.2.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.1-t64btWfiMa44UE3pSm6kk
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2
    primitive-0.7.4.0-6AwD3HztCbd2gLkP35eH21
    syb-0.7.2.4-ITLgxVljDYrB4znIftQFlX template-haskell-2.18.0.0
    text-1.2.5.0 th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    th-orphans-0.13.14-6ixTF41USOJCfCMjxisKGS

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-utilities-0.2.5.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-utilities
version:              0.2.5.1
visibility:           public
id:                   th-utilities-0.2.5.1-KnN8nblk9bDCToCP8ez4Ny
key:                  th-utilities-0.2.5.1-KnN8nblk9bDCToCP8ez4Ny
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  260c83f763d9c97da19c4fc546084a39
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/th-utilities-0.2.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/th-utilities-0.2.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.1-KnN8nblk9bDCToCP8ez4Ny
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2
    primitive-0.7.4.0-EiSZDHCiiZa24trDAETdpw
    syb-0.7.2.4-7ynUdJcB17N8mF8LpyS12V template-haskell-2.18.0.0
    text-1.2.5.0 th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    th-orphans-0.13.14-FgewTneKYBDAPpiw3v4v4b

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
